@@ -1,11 +1,10 @@
-import jsend
-from jsend import *
+# import jsend
+from .jsend import Message, make_successful_message, make_failed_message, SuccessfulMessage, FailedMessage
 
-__all__ = jsend.__all__
 
 __author__ = 'darkdarkfruit'
 
-VERSION = (0, 7, 1)
+VERSION = (0, 9, 2)
 
 def get_version():
     version = '%s.%s' % (VERSION[0], VERSION[1])
